summaryrefslogtreecommitdiff
path: root/types.h
diff options
context:
space:
mode:
Diffstat (limited to 'types.h')
-rw-r--r--types.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/types.h b/types.h
index b7c1b0b..f3fa76c 100644
--- a/types.h
+++ b/types.h
@@ -501,9 +501,10 @@ enum {
};
typedef struct StructDef {
Field *fields;
+ struct Declaration *constants;
Location where;
U8 flags;
- Block scope; /* to make sure that parameters live somewhere. fields are not kept here. */
+ Block scope; /* to make sure that parameters and constants live somewhere. fields are not kept here. */
union {
HashTable instances;
struct {
@@ -831,6 +832,7 @@ typedef struct Expression {
};
} Expression;
+
typedef struct Argument {
Location where;
char *name; /* NULL = no name */